.. rubric:: Removals and deprecations

- The module `xotl.tools.fs.path`:mod: is deprecated.

- All functions in `xotl.tools.decorator`:mod: were removed.  The entire
  package is not deprecated and slotted for removal in 3.4.0.

- The module `!xotl.tools.future.graphlib`:mod: was removed.

- The module `!xotl.tools.deprecation`:mod: was removed.

.. rubric:: Typing changes

- Fixes type-hint bugs of `xotl.tool.objects.iter_branch_subclasses`:func: and
  `xotl.tools.objects.get_branch_subclasses`:func:.
